@@ -17,13 +17,8 @@
 // GPL Exception version 1.1, which can be found in the file
 // GPL_EXCEPTION.txt in this package.
 // 
-// Please review the following information to ensure GNU General
-// Public Licensing requirements will be met:
-// http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-// you are unsure which license is appropriate for your use, please
-// review the following information:
-// http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-// or contact the sales department at sales@riverbankcomputing.com.
+// If you are unsure which license is appropriate for your use, please
+// contact the sales department at sales@riverbankcomputing.com.
 // 
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -44,12 +39,16 @@ extern "C++" {
 #include <qcstring.h>
 
 #include <Qsci/qsciglobal.h>
+#include <Qsci/qscicommand.h>
 #include <Qsci/qscidocument.h>
 #include <Qsci/qsciscintillabase.h>
 
 
 QT_BEGIN_NAMESPACE
+class QAction;
+class QImage;
 class QIODevice;
+class QMenu;
 class QPoint;
 QT_END_NAMESPACE
 
@@ -57,7 +56,7 @@ class QsciCommandSet;
 class QsciLexer;
 class QsciStyle;
 class QsciStyledText;
-class ListBoxQt;
+class QsciListBoxQt;
 
 
 //! \brief The QsciScintilla class implements a higher level, more Qt-like,
@@ -225,30 +224,58 @@ public:
 
     //! This enum defines the different indicator styles.
     enum IndicatorStyle {
-        // A single straight underline.
+        //! A single straight underline.
         PlainIndicator = INDIC_PLAIN,
 
-        // A squiggly underline.
+        //! A squiggly underline that requires 3 pixels of descender space.
         SquiggleIndicator = INDIC_SQUIGGLE,
 
-        // A line of small T shapes.
+        //! A line of small T shapes.
         TTIndicator = INDIC_TT,
 
-        // Diagonal hatching.
+        //! Diagonal hatching.
         DiagonalIndicator = INDIC_DIAGONAL,
 
-        // Strike out.
+        //! Strike out.
         StrikeIndicator = INDIC_STRIKE,
 
-        // An indicator with no visual appearence.
+        //! An indicator with no visual appearence.
         HiddenIndicator = INDIC_HIDDEN,
 
-        // A rectangle around the text.
+        //! A rectangle around the text.
         BoxIndicator = INDIC_BOX,
 
-        // A rectangle with rounded corners around the text with the interior
-        // more transparent than the border.
-        RoundBoxIndicator = INDIC_ROUNDBOX
+        //! A rectangle with rounded corners around the text with the interior
+        //! usually more transparent than the border.
+        RoundBoxIndicator = INDIC_ROUNDBOX,
+
+        //! A rectangle around the text with the interior usually more
+        //! transparent than the border.
+        StraightBoxIndicator = INDIC_STRAIGHTBOX,
+
+        //! A dashed underline.
+        DashesIndicator = INDIC_DASH,
+
+        //! A dotted underline.
+        DotsIndicator = INDIC_DOTS,
+
+        //! A squiggly underline that requires 2 pixels of descender space and
+        //! so will fit under smaller fonts.
+        SquiggleLowIndicator = INDIC_SQUIGGLELOW,
+
+        //! A dotted rectangle around the text with the interior usually more
+        //! transparent than the border.
+        DotBoxIndicator = INDIC_DOTBOX
+    };
+
+    //! This enum defines the different margin options.
+    enum {
+        //! Reset all margin options.
+        MoNone = SC_MARGINOPTION_NONE,
+
+        //! If this is set then only the first sub-line of a wrapped line will
+        //! be selected when clicking on a margin.
+        MoSublineSelect = SC_MARGINOPTION_SUBLINESELECT
     };
 
     //! This enum defines the different margin types.
@@ -584,6 +611,7 @@ public:
     //! \sa eolMode(), setEolMode()
     void convertEols(EolMode mode);
 
+
     //! Returns the attached document.
     //!
     //! \sa setDocument()
@@ -671,10 +699,14 @@ public:
     //! If \a show is true (the default) then any text found is made visible
     //! (ie. it is unfolded).
     //!
+    //! If \a posix is true then a regular expression is treated in a more
+    //! POSIX compatible manner by interpreting bare ( and ) as tagged sections
+    //! rather than \( and \).
+    //!
     //! \sa findNext(), replace()
     virtual bool findFirst(const QString &expr, bool re, bool cs, bool wo,
             bool wrap, bool forward = true, int line = -1, int index = -1,
-            bool show = true);
+            bool show = true, bool posix = false);
 
     //! Find the next occurence of the string found using findFirst().
     //!
@@ -835,6 +867,11 @@ public:
     //! \sa setMarginMask(), QsciMarker, SCI_GETMARGINMASKN
     int marginMarkerMask(int margin) const;
 
+    //! Returns the margin options.  The default is MoNone.
+    //!
+    //! \sa setMarginOptions(), MoNone, MoSublineSelect.
+    int marginOptions() const;
+
     //! Returns true if margin \a margin is sensitive to mouse clicks.
     //!
     //! \sa setMarginSensitivity(), marginClicked(), SCI_GETMARGINTYPEN
@@ -884,6 +921,12 @@ public:
     //! many markers have been defined.
     int markerDefine(const QPixmap &pm, int markerNumber = -1);
 
+    //! Define a marker using a copy of the image \a im with the marker number
+    //! \a markerNumber.  If \a markerNumber is -1 then the marker number is
+    //! automatically allocated.  The marker number is returned or -1 if too
+    //! many markers have been defined.
+    int markerDefine(const QImage &im, int markerNumber = -1);
+
     //! Add an instance of marker number \a markerNumber to line number
     //! \a linenr.  A handle for the marker is returned which can be used to
     //! track the marker's position, or -1 if the \a markerNumber was invalid.
@@ -963,6 +1006,12 @@ public:
     //! \sa clearRegisteredImages(), QsciLexer::apiLoad()
     void registerImage(int id, const QPixmap &pm);
 
+    //! Register an image \a im with ID \a id.  Registered images can be
+    //! displayed in auto-completion lists.
+    //!
+    //! \sa clearRegisteredImages(), QsciLexer::apiLoad()
+    void registerImage(int id, const QImage &im);
+
     //! Replace the current selection, set by a previous call to findFirst() or
     //! findNext(), with \a replaceStr.
     //!
@@ -1082,6 +1131,16 @@ public:
     //! If \a indicatorNumber is -1 then the colour of all indicators is set.
     void setIndicatorForegroundColor(const QColor &col, int indicatorNumber = -1);
 
+    //! Set the outline colour of indicator \a indicatorNumber to \a col.
+    //! If \a indicatorNumber is -1 then the colour of all indicators is set.
+    //! At the moment only the alpha value of the colour has any affect.
+    void setIndicatorOutlineColor(const QColor &col, int indicatorNumber = -1);
+
+    //! Set the margin options to \a options.
+    //!
+    //! \sa marginOptions(), MoNone, MoSublineSelect.
+    void setMarginOptions(int options);
+
     //! Set the margin text of line \a line with the text \a text using the
     //! style number \a style.
     void setMarginText(int line, const QString &text, int style);
@@ -1120,30 +1179,52 @@ public:
     //! \sa setMarkerBackgroundColor()
     void setMarkerForegroundColor(const QColor &col, int markerNumber = -1);
 
-    //! Set the background colour used to display matched braces to \a col.
-    //! The default is white.
+    //! Set the background colour used to display matched braces to \a col.  It
+    //! is ignored if an indicator is being used.  The default is white.
     //!
-    //! \sa setMatchedBraceForegroundColor()
+    //! \sa setMatchedBraceForegroundColor(), setMatchedBraceIndicator()
     void setMatchedBraceBackgroundColor(const QColor &col);
 
-    //! Set the foreground colour used to display matched braces to \a col.
-    //! The default is red.
+    //! Set the foreground colour used to display matched braces to \a col.  It
+    //! is ignored if an indicator is being used.  The default is red.
     //!
-    //! \sa setMatchedBraceBackgroundColor()
+    //! \sa setMatchedBraceBackgroundColor(), setMatchedBraceIndicator()
     void setMatchedBraceForegroundColor(const QColor &col);
 
-    //! Set the background colour used to display unmatched braces to \a col.
-    //! The default is white.
+    //! Set the indicator used to display matched braces to \a indicatorNumber.
+    //! The default is not to use an indicator.
     //!
-    //! \sa setUnmatchedBraceForegroundColor()
+    //! \sa resetMatchedBraceIndicator(), setMatchedBraceBackgroundColor()
+    void setMatchedBraceIndicator(int indicatorNumber);
+
+    //! Stop using an indicator to display matched braces.
+    //!
+    //! \sa setMatchedBraceIndicator()
+    void resetMatchedBraceIndicator();
+
+    //! Set the background colour used to display unmatched braces to \a col.
+    //! It is ignored if an indicator is being used.  The default is white.
+    //!
+    //! \sa setUnmatchedBraceForegroundColor(), setUnmatchedBraceIndicator()
     void setUnmatchedBraceBackgroundColor(const QColor &col);
 
     //! Set the foreground colour used to display unmatched braces to \a col.
-    //! The default is blue.
+    //! It is ignored if an indicator is being used.  The default is blue.
     //!
-    //! \sa setUnmatchedBraceBackgroundColor()
+    //! \sa setUnmatchedBraceBackgroundColor(), setUnmatchedBraceIndicator()
     void setUnmatchedBraceForegroundColor(const QColor &col);
 
+    //! Set the indicator used to display unmatched braces to
+    //! \a indicatorNumber.  The default is not to use an indicator.
+    //!
+    //! \sa resetUnmatchedBraceIndicator(), setUnmatchedBraceBackgroundColor()
+    void setUnmatchedBraceIndicator(int indicatorNumber);
+
+    //! Stop using an indicator to display unmatched braces.
+    //!
+    //! \sa setUnmatchedBraceIndicator()
+    void resetUnmatchedBraceIndicator();
+
     //! Set the visual flags displayed when a line is wrapped.  \a endFlag
     //! determines if and where the flag at the end of a line is displayed.
     //! \a startFlag determines if and where the flag at the start of a line is
@@ -1782,6 +1863,8 @@ signals:
     //! \sa showUserList()
     void userListActivated(int id, const QString &string);
 
+protected:
+
 private slots:
     void handleCallTipClick(int dir);
     void handleCharAdded(int charadded);
@@ -1805,6 +1888,7 @@ private slots:
 
     void handleUpdateUI(int updated);
 
+
 private:
     typedef QCString ScintillaString;
 
@@ -1906,14 +1990,15 @@ private:
     QCString explicit_fillups;
     bool fillups_enabled;
 
-    // The following allow ListBoxQt to distinguish between an auto-completion
-    // list and a user list, and to return the full selection of an
-    // auto-completion list.
-    friend class ListBoxQt;
+    // The following allow QsciListBoxQt to distinguish between an
+    // auto-completion list and a user list, and to return the full selection
+    // of an auto-completion list.
+    friend class QsciListBoxQt;
 
     QString acSelection;
     bool isAutoCompletionList() const;
 
+
     QsciScintilla(const QsciScintilla &);
     QsciScintilla &operator=(const QsciScintilla &);
 };
