@@ -16,13 +16,8 @@
 // GPL Exception version 1.1, which can be found in the file
 // GPL_EXCEPTION.txt in this package.
 // 
-// Please review the following information to ensure GNU General
-// Public Licensing requirements will be met:
-// http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-// you are unsure which license is appropriate for your use, please
-// review the following information:
-// http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-// or contact the sales department at sales@riverbankcomputing.com.
+// If you are unsure which license is appropriate for your use, please
+// contact the sales department at sales@riverbankcomputing.com.
 // 
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -315,6 +310,8 @@ QFont QsciLexerHTML::defaultFont(int style) const
     case Entity:
 #if defined(Q_OS_WIN)
         f = QFont("Times New Roman",11);
+#elif defined(Q_OS_MAC)
+        f = QFont("Times New Roman", 12);
 #else
         f = QFont("Bitstream Charter",10);
 #endif
@@ -323,6 +320,8 @@ QFont QsciLexerHTML::defaultFont(int style) const
     case HTMLComment:
 #if defined(Q_OS_WIN)
         f = QFont("Verdana",9);
+#elif defined(Q_OS_MAC)
+        f = QFont("Verdana", 12);
 #else
         f = QFont("Bitstream Vera Sans",8);
 #endif
@@ -351,6 +350,8 @@ QFont QsciLexerHTML::defaultFont(int style) const
     case ASPJavaScriptSymbol:
 #if defined(Q_OS_WIN)
         f = QFont("Comic Sans MS",9);
+#elif defined(Q_OS_MAC)
+        f = QFont("Comic Sans MS", 12);
 #else
         f = QFont("Bitstream Vera Serif",9);
 #endif
@@ -376,6 +377,8 @@ QFont QsciLexerHTML::defaultFont(int style) const
     case PHPComment:
 #if defined(Q_OS_WIN)
         f = QFont("Comic Sans MS",9);
+#elif defined(Q_OS_MAC)
+        f = QFont("Comic Sans MS", 12);
 #else
         f = QFont("Bitstream Vera Serif",9);
 #endif
@@ -393,6 +396,8 @@ QFont QsciLexerHTML::defaultFont(int style) const
     case ASPVBScriptUnclosedString:
 #if defined(Q_OS_WIN)
         f = QFont("Lucida Sans Unicode",9);
+#elif defined(Q_OS_MAC)
+        f = QFont("Lucida Grande", 12);
 #else
         f = QFont("Bitstream Vera Serif",9);
 #endif
@@ -402,6 +407,8 @@ QFont QsciLexerHTML::defaultFont(int style) const
     case ASPVBScriptKeyword:
 #if defined(Q_OS_WIN)
         f = QFont("Lucida Sans Unicode",9);
+#elif defined(Q_OS_MAC)
+        f = QFont("Lucida Grande", 12);
 #else
         f = QFont("Bitstream Vera Serif",9);
 #endif
@@ -414,6 +421,8 @@ QFont QsciLexerHTML::defaultFont(int style) const
     case ASPPythonSingleQuotedString:
 #if defined(Q_OS_WIN)
         f = QFont("Courier New",10);
+#elif defined(Q_OS_MAC)
+        f = QFont("Courier New", 12);
 #else
         f = QFont("Bitstream Vera Sans Mono",9);
 #endif
@@ -429,6 +438,8 @@ QFont QsciLexerHTML::defaultFont(int style) const
     case PHPCommentLine:
 #if defined(Q_OS_WIN)
         f = QFont("Comic Sans MS",9);
+#elif defined(Q_OS_MAC)
+        f = QFont("Comic Sans MS", 12);
 #else
         f = QFont("Bitstream Vera Serif",9);
 #endif
