@@ -1,6 +1,6 @@
 // This module implements the portability layer for the Qt port of Scintilla.
 //
-// Copyright (c) 2010 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2011 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
 // This file is part of QScintilla.
 // 
@@ -16,13 +16,8 @@
 // GPL Exception version 1.1, which can be found in the file
 // GPL_EXCEPTION.txt in this package.
 // 
-// Please review the following information to ensure GNU General
-// Public Licensing requirements will be met:
-// http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-// you are unsure which license is appropriate for your use, please
-// review the following information:
-// http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-// or contact the sales department at sales@riverbankcomputing.com.
+// If you are unsure which license is appropriate for your use, please
+// contact the sales department at sales@riverbankcomputing.com.
 // 
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -46,27 +41,33 @@
 #include <qdesktopwidget.h>
 #include <qpolygon.h>
 
+#include "SciNamespace.h"
+
 #include "Platform.h"
 #include "XPM.h"
 
 #include "Qsci/qsciscintillabase.h"
 #include "SciClasses.h"
 
+#include "FontQuality.h"
+
+
+QSCI_BEGIN_SCI_NAMESPACE
 
 // Type convertors.
-static QFont *PFont(FontID id)
+static QFont *PFont(FontID fid)
 {
-    return reinterpret_cast<QFont *>(id);
+    return reinterpret_cast<QFont *>(fid);
 }
 
-static QWidget *PWindow(WindowID id)
+static QWidget *PWindow(WindowID wid)
 {
-    return reinterpret_cast<QWidget *>(id);
+    return reinterpret_cast<QWidget *>(wid);
 }
 
-static SciPopup *PMenu(MenuID id)
+static QsciSciPopup *PMenu(MenuID mid)
 {
-    return reinterpret_cast<SciPopup *>(id);
+    return reinterpret_cast<QsciSciPopup *>(mid);
 }
 
 
@@ -108,7 +109,7 @@ void Palette::Allocate(Window &)
 
 
 // Font management.
-Font::Font() : id(0)
+Font::Font() : fid(0)
 {
 }
 
@@ -117,15 +118,43 @@ Font::~Font()
 }
 
 void Font::Create(const char *faceName, int, int size, bool bold, bool italic,
-        bool)
+        int flags)
 {
     Release();
 
     QFont *f = new QFont();
 
+    QFont::StyleStrategy strategy;
+
+    switch (flags & SC_EFF_QUALITY_MASK)
+    {
+    case SC_EFF_QUALITY_NON_ANTIALIASED:
+        strategy = QFont::NoAntialias;
+        break;
+
+    case SC_EFF_QUALITY_ANTIALIASED:
+        strategy = QFont::PreferAntialias;
+        break;
+
+    default:
+        strategy = QFont::PreferDefault;
+    }
+
+#if defined(Q_WS_MAC)
+#if QT_VERSION >= 0x040700
+    strategy = static_cast<QFont::StyleStrategy>(strategy | QFont::ForceIntegerMetrics);
+#else
+#warning "Correct handling of QFont metrics requires Qt v4.7.0 or later"
+#endif
+#endif
+
+    f->setStyleStrategy(strategy);
+
     // If name of the font begins with a '-', assume, that it is an XLFD.
     if (faceName[0] == '-')
+    {
         f->setRawName(faceName);
+    }
     else
     {
         f->setFamily(faceName);
@@ -134,15 +163,15 @@ void Font::Create(const char *faceName, int, int size, bool bold, bool italic,
         f->setItalic(italic);
     }
 
-    id = f;
+    fid = f;
 }
 
 void Font::Release()
 {
-    if (id)
+    if (fid)
     {
-        delete PFont(id);
-        id = 0;
+        delete PFont(fid);
+        fid = 0;
     }
 }
 
@@ -177,6 +206,7 @@ public:
     void AlphaRectangle(PRectangle rc, int cornerSize, ColourAllocated fill,
             int alphaFill, ColourAllocated outline, int alphaOutline,
             int flags);
+    void DrawRGBAImage(PRectangle rc, int width, int height, const unsigned char *pixelsImage);
     void Ellipse(PRectangle rc, ColourAllocated fore, ColourAllocated back);
     void Copy(PRectangle rc, Point from, Surface &surfaceSource);
 
@@ -484,6 +514,20 @@ void SurfaceImpl::DrawXPM(PRectangle rc, const XPM *xpm)
     painter->drawPixmap(x, y, qpm);
 }
 
+void SurfaceImpl::DrawRGBAImage(PRectangle rc, int width, int height,
+        const unsigned char *pixelsImage)
+{
+    Q_ASSERT(painter);
+
+    int x, y;
+    const QImage *qim = reinterpret_cast<const QImage *>(pixelsImage);
+
+    x = rc.left + (rc.Width() - width) / 2;
+    y = rc.top + (rc.Height() - height) / 2;
+
+    painter->drawImage(x, y, *qim);
+}
+
 void SurfaceImpl::MeasureWidths(Font &font_, const char *s, int len,
         int *positions)
 {
@@ -492,11 +536,13 @@ void SurfaceImpl::MeasureWidths(Font &font_, const char *s, int len,
 
     // The position for each byte of a character is the offset from the start
     // where the following character should be drawn.
-    int i_byte = 0, width = 0;
+    int i_byte = 0;
 
     for (int i_char = 0; i_char < qs.length(); ++i_char)
     {
-        width += fm.width(qs.at(i_char));
+        // We can't just add the individual character widths together because
+        // of kerning.
+        int width = fm.width(qs.left(i_char + 1));
 
         if (unicodeMode)
         {
@@ -604,7 +650,7 @@ Window::~Window()
 
 void Window::Destroy()
 {
-    QWidget *w = PWindow(id);
+    QWidget *w = PWindow(wid);
 
     if (w)
     {
@@ -615,18 +661,18 @@ void Window::Destroy()
         // around the problem but this is the simplest and doesn't seem to
         // cause problems of its own.
         w->deleteLater();
-        id = 0;
+        wid = 0;
     }
 }
 
 bool Window::HasFocus()
 {
-    return PWindow(id)->hasFocus();
+    return PWindow(wid)->hasFocus();
 }
 
 PRectangle Window::GetPosition()
 {
-    QWidget *w = PWindow(id);
+    QWidget *w = PWindow(wid);
 
     // Before any size allocated pretend its big enough not to be scrolled.
     PRectangle rc(0,0,5000,5000);
@@ -644,19 +690,19 @@ PRectangle Window::GetPosition()
 
 void Window::SetPosition(PRectangle rc)
 {
-    PWindow(id)->setGeometry(rc.left, rc.top, rc.right - rc.left,
+    PWindow(wid)->setGeometry(rc.left, rc.top, rc.right - rc.left,
             rc.bottom - rc.top);
 }
 
 void Window::SetPositionRelative(PRectangle rc, Window relativeTo)
 {
-    QWidget *rel = PWindow(relativeTo.id);
+    QWidget *rel = PWindow(relativeTo.wid);
     QPoint pos = rel->mapToGlobal(rel->pos());
 
     int x = pos.x() + rc.left;
     int y = pos.y() + rc.top;
 
-    PWindow(id)->setGeometry(x, y, rc.right - rc.left, rc.bottom - rc.top);
+    PWindow(wid)->setGeometry(x, y, rc.right - rc.left, rc.bottom - rc.top);
 }
 
 PRectangle Window::GetClientPosition()
@@ -666,7 +712,7 @@ PRectangle Window::GetClientPosition()
 
 void Window::Show(bool show)
 {
-    QWidget *w = PWindow(id);
+    QWidget *w = PWindow(wid);
 
     if (show)
         w->show();
@@ -676,7 +722,7 @@ void Window::Show(bool show)
 
 void Window::InvalidateAll()
 {
-    QWidget *w = PWindow(id);
+    QWidget *w = PWindow(wid);
 
     if (w)
         w->update();
@@ -684,7 +730,7 @@ void Window::InvalidateAll()
 
 void Window::InvalidateRectangle(PRectangle rc)
 {
-    QWidget *w = PWindow(id);
+    QWidget *w = PWindow(wid);
 
     if (w)
         w->update(rc.left, rc.top, rc.right - rc.left, rc.bottom - rc.top);
@@ -692,7 +738,7 @@ void Window::InvalidateRectangle(PRectangle rc)
 
 void Window::SetFont(Font &font)
 {
-    PWindow(id)->setFont(*PFont(font.GetID()));
+    PWindow(wid)->setFont(*PFont(font.GetID()));
 }
 
 void Window::SetCursor(Cursor curs)
@@ -726,53 +772,55 @@ void Window::SetCursor(Cursor curs)
         break;
 
     default:
+        // Note that Qt doesn't have a standard cursor that could be used to
+        // implement cursorReverseArrow.
         qc = Qt::ArrowCursor;
     }
 
-    PWindow(id)->setCursor(qc);
+    PWindow(wid)->setCursor(qc);
 }
 
 void Window::SetTitle(const char *s)
 {
-    PWindow(id)->setWindowTitle(s);
+    PWindow(wid)->setWindowTitle(s);
 }
 
 
 PRectangle Window::GetMonitorRect(Point pt)
 {
-    QPoint qpt = PWindow(id)->mapToGlobal(QPoint(pt.x, pt.y));
+    QPoint qpt = PWindow(wid)->mapToGlobal(QPoint(pt.x, pt.y));
     QRect qr = QApplication::desktop()->availableGeometry(qpt);
-    qpt = PWindow(id)->mapFromGlobal(qr.topLeft());
+    qpt = PWindow(wid)->mapFromGlobal(qr.topLeft());
 
     return PRectangle(qpt.x(), qpt.y(), qpt.x() + qr.width(), qpt.y() + qr.height());
 }
 
 
 // Menu management.
-Menu::Menu() : id(0)
+Menu::Menu() : mid(0)
 {
 }
 
 void Menu::CreatePopUp()
 {
     Destroy();
-    id = new SciPopup();
+    mid = new QsciSciPopup();
 }
 
 void Menu::Destroy()
 {
-    SciPopup *m = PMenu(id);
+    QsciSciPopup *m = PMenu(mid);
 
     if (m)
     {
         delete m;
-        id = 0;
+        mid = 0;
     }
 }
 
 void Menu::Show(Point pt, Window &)
 {
-    PMenu(id)->popup(QPoint(pt.x, pt.y));
+    PMenu(mid)->popup(QPoint(pt.x, pt.y));
 }
 
 
@@ -983,3 +1031,5 @@ void Platform::Assert(const char *c, const char *file, int line)
 {
     qFatal("Assertion [%s] failed at %s %d\n", c, file, line);
 }
+
+QSCI_END_SCI_NAMESPACE
