@@ -16,13 +16,8 @@
 // GPL Exception version 1.1, which can be found in the file
 // GPL_EXCEPTION.txt in this package.
 // 
-// Please review the following information to ensure GNU General
-// Public Licensing requirements will be met:
-// http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-// you are unsure which license is appropriate for your use, please
-// review the following information:
-// http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-// or contact the sales department at sales@riverbankcomputing.com.
+// If you are unsure which license is appropriate for your use, please
+// contact the sales department at sales@riverbankcomputing.com.
 // 
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -103,7 +98,7 @@ QsciScintillaBase::QsciScintillaBase(QWidget *parent)
 
     triple_click.setSingleShot(true);
 
-    sci = new ScintillaQt(this);
+    sci = new QsciScintillaQt(this);
 
     SendScintilla(SCI_SETCARETPERIOD, QApplication::cursorFlashTime() / 2);
 
@@ -204,7 +199,7 @@ long QsciScintillaBase::SendScintilla(unsigned int msg, int wParam) const
 long QsciScintillaBase::SendScintilla(unsigned int msg, long cpMin, long cpMax,
         char *lpstrText) const
 {
-    TextRange tr;
+    QSCI_SCI_NAMESPACE(TextRange) tr;
 
     tr.chrg.cpMin = cpMin;
     tr.chrg.cpMax = cpMax;
@@ -238,9 +233,9 @@ long QsciScintillaBase::SendScintilla(unsigned int msg, const QColor &col) const
 long QsciScintillaBase::SendScintilla(unsigned int msg, unsigned long wParam,
         QPainter *hdc, const QRect &rc, long cpMin, long cpMax) const
 {
-    RangeToFormat rf;
+    QSCI_SCI_NAMESPACE(RangeToFormat) rf;
 
-    rf.hdc = rf.hdcTarget = reinterpret_cast<SurfaceID>(hdc);
+    rf.hdc = rf.hdcTarget = reinterpret_cast<QSCI_SCI_NAMESPACE(SurfaceID)>(hdc);
 
     rf.rc.left = rc.left();
     rf.rc.top = rc.top();
@@ -262,6 +257,14 @@ long QsciScintillaBase::SendScintilla(unsigned int msg, unsigned long wParam,
 }
 
 
+// Overloaded message send.
+long QsciScintillaBase::SendScintilla(unsigned int msg, unsigned long wParam,
+        const QImage &lParam) const
+{
+    return sci->WndProc(msg, wParam, reinterpret_cast<sptr_t>(&lParam));
+}
+
+
 // Send a message to the real Scintilla widget using the low level Scintilla
 // API that returns a pointer result.
 void *QsciScintillaBase::SendScintillaPtrResult(unsigned int msg) const
@@ -271,7 +274,7 @@ void *QsciScintillaBase::SendScintillaPtrResult(unsigned int msg) const
 }
 
 
-// Handle the timer on behalf of the ScintillaQt instance.
+// Handle the timer on behalf of the QsciScintillaQt instance.
 void QsciScintillaBase::handleTimer()
 {
     sci->Tick();
@@ -281,7 +284,7 @@ void QsciScintillaBase::handleTimer()
 // Re-implemented to handle the context menu.
 void QsciScintillaBase::contextMenuEvent(QContextMenuEvent *e)
 {
-    sci->ContextMenu(Point(e->globalX(), e->globalY()));
+    sci->ContextMenu(QSCI_SCI_NAMESPACE(Point)(e->globalX(), e->globalY()));
 }
 
 
@@ -320,12 +323,20 @@ void QsciScintillaBase::handleSelection()
 // Handle key presses.
 void QsciScintillaBase::keyPressEvent(QKeyEvent *e)
 {
-    unsigned key;
+    unsigned key, modifiers = 0;
     QByteArray utf8;
 
-    bool shift = e->modifiers() & Qt::ShiftModifier;
-    bool ctrl = e->modifiers() & Qt::ControlModifier;
-    bool alt = e->modifiers() & Qt::AltModifier;
+    if (e->modifiers() & Qt::ShiftModifier)
+        modifiers |= SCMOD_SHIFT;
+
+    if (e->modifiers() & Qt::ControlModifier)
+        modifiers |= SCMOD_CTRL;
+
+    if (e->modifiers() & Qt::AltModifier)
+        modifiers |= SCMOD_ALT;
+
+    if (e->modifiers() & Qt::MetaModifier)
+        modifiers |= SCMOD_META;
 
     switch (e->key())
     {
@@ -384,7 +395,7 @@ void QsciScintillaBase::keyPressEvent(QKeyEvent *e)
     case Qt::Key_Backtab:
         // Scintilla assumes a backtab is shift-tab.
         key = SCK_TAB;
-        shift = true;
+        modifiers |= SCMOD_SHIFT;
         break;
 
     case Qt::Key_Return:
@@ -406,9 +417,9 @@ void QsciScintillaBase::keyPressEvent(QKeyEvent *e)
 
     default:
         // See if the input was a single ASCII key.  If so it will be passed to
-        // KeyDown to allow it to be filtered.  Correct the modifiers and key
-        // for ASCII letters as Qt uses the ASCII code of uppercase letters for
-        // Key_A etc.
+        // KeyDownWithModifiers to allow it to be filtered.  Correct the
+        // modifiers and key for ASCII letters as Qt uses the ASCII code of
+        // uppercase letters for Key_A etc.
         utf8 = e->text().toUtf8();
 
         if (utf8.length() == 0)
@@ -420,11 +431,11 @@ void QsciScintillaBase::keyPressEvent(QKeyEvent *e)
         else if (key >= 0x01 && key <= 0x1a)
             key += 0x40;
         else if (key >= 'A' && key <= 'Z')
-            shift = true;
+            modifiers |= true;
         else if (key >= 'a' && key <= 'z')
         {
             key -= 0x20;
-            shift = false;
+            modifiers &= ~SCMOD_SHIFT;
         }
     }
 
@@ -432,7 +443,7 @@ void QsciScintillaBase::keyPressEvent(QKeyEvent *e)
     {
         bool consumed = false;
 
-        sci->KeyDown(key, shift, ctrl, alt, &consumed);
+        sci->KeyDownWithModifiers(key, modifiers, &consumed);
 
         if (consumed)
         {
@@ -476,13 +487,14 @@ void QsciScintillaBase::mouseDoubleClickEvent(QMouseEvent *e)
     setFocus();
 
     // Make sure Scintilla will interpret this as a double-click.
-    unsigned clickTime = sci->lastClickTime + Platform::DoubleClickTime() - 1;
+    unsigned clickTime = sci->lastClickTime + QSCI_SCI_NAMESPACE(Platform)::DoubleClickTime() - 1;
 
     bool shift = e->modifiers() & Qt::ShiftModifier;
     bool ctrl = e->modifiers() & Qt::ControlModifier;
     bool alt = e->modifiers() & Qt::AltModifier;
 
-    sci->ButtonDown(Point(e->x(), e->y()), clickTime, shift, ctrl, alt);
+    sci->ButtonDown(QSCI_SCI_NAMESPACE(Point)(e->x(), e->y()), clickTime,
+            shift, ctrl, alt);
 
     // Remember the current position and time in case it turns into a triple
     // click.
@@ -494,7 +506,7 @@ void QsciScintillaBase::mouseDoubleClickEvent(QMouseEvent *e)
 // Handle a mouse move.
 void QsciScintillaBase::mouseMoveEvent(QMouseEvent *e)
 {
-    sci->ButtonMove(Point(e->x(), e->y()));
+    sci->ButtonMove(QSCI_SCI_NAMESPACE(Point)(e->x(), e->y()));
 }
 
 
@@ -503,7 +515,7 @@ void QsciScintillaBase::mousePressEvent(QMouseEvent *e)
 {
     setFocus();
 
-    Point pt(e->x(), e->y());
+    QSCI_SCI_NAMESPACE(Point) pt(e->x(), e->y());
 
     if (e->button() == Qt::LeftButton)
     {
@@ -512,9 +524,9 @@ void QsciScintillaBase::mousePressEvent(QMouseEvent *e)
         // It is a triple click if the timer is running and the mouse hasn't
         // moved too much.
         if (triple_click.isActive() && (e->globalPos() - triple_click_at).manhattanLength() < QApplication::startDragDistance())
-            clickTime = sci->lastClickTime + Platform::DoubleClickTime() - 1;
+            clickTime = sci->lastClickTime + QSCI_SCI_NAMESPACE(Platform)::DoubleClickTime() - 1;
         else
-            clickTime = sci->lastClickTime + Platform::DoubleClickTime() + 1;
+            clickTime = sci->lastClickTime + QSCI_SCI_NAMESPACE(Platform)::DoubleClickTime() + 1;
 
         triple_click.stop();
 
@@ -556,7 +568,7 @@ void QsciScintillaBase::mouseReleaseEvent(QMouseEvent *e)
     {
         bool ctrl = e->modifiers() & Qt::ControlModifier;
 
-        sci->ButtonUp(Point(e->x(), e->y()), 0, ctrl);
+        sci->ButtonUp(QSCI_SCI_NAMESPACE(Point)(e->x(), e->y()), 0, ctrl);
     }
 }
 
@@ -606,7 +618,7 @@ void QsciScintillaBase::dragEnterEvent(QDragEnterEvent *e)
 // Handle drag leaves.
 void QsciScintillaBase::dragLeaveEvent(QDragLeaveEvent *)
 {
-    sci->SetDragPosition(SelectionPosition());
+    sci->SetDragPosition(QSCI_SCI_NAMESPACE(SelectionPosition)());
 }
 
 
@@ -614,7 +626,8 @@ void QsciScintillaBase::dragLeaveEvent(QDragLeaveEvent *)
 void QsciScintillaBase::dragMoveEvent(QDragMoveEvent *e)
 {
     sci->SetDragPosition(
-            sci->SPositionFromLocation(Point(e->pos().x(), e->pos().y()),
+            sci->SPositionFromLocation(
+                    QSCI_SCI_NAMESPACE(Point)(e->pos().x(), e->pos().y()),
                     false, false, sci->UserVirtualSpace()));
 
     acceptAction(e);
@@ -647,18 +660,9 @@ void QsciScintillaBase::dropEvent(QDropEvent *e)
 void QsciScintillaBase::acceptAction(QDropEvent *e)
 {
     if (sci->pdoc->IsReadOnly() || !canInsertFromMimeData(e->mimeData()))
-    {
         e->ignore();
-    }
-    else if ((e->source() == this || e->source() == viewport()) && (e->keyboardModifiers() & Qt::ControlModifier) == 0)
-    {
-        e->setDropAction(Qt::MoveAction);
-        e->accept();
-    }
     else
-    {
         e->acceptProposedAction();
-    }
 }
 
 
